==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicySubjectReviewFluent<A extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec getSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec buildSpec();
  public A withSpec(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec spec);
  public java.lang.Boolean hasSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item);
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus getStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus buildStatus();
  public A withStatus(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus status);
  public java.lang.Boolean hasStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item);
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item);
  public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusFluent<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityPolicySubjectReviewFluent<A extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec getSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec buildSpec();
  public A withSpec(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec spec);
  public java.lang.Boolean hasSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item);
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpec();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus getStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus buildStatus();
  public A withStatus(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus status);
  public java.lang.Boolean hasStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item);
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatus();
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluent<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusFluent<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
